@@ -96,6 +96,8 @@ typedef enum { /*< prefix=CLUTTER_ROTATE >*/
  * ClutterRequestMode:
  * @CLUTTER_REQUEST_HEIGHT_FOR_WIDTH: Height for width requests
  * @CLUTTER_REQUEST_WIDTH_FOR_HEIGHT: Width for height requests
+ * @CLUTTER_REQUEST_CONTENT_SIZE: Use the preferred size of the
+ *   #ClutterContent, if it has any (available since 1.22)
  *
  * Specifies the type of requests for a #ClutterActor.
  *
@@ -103,7 +105,8 @@ typedef enum { /*< prefix=CLUTTER_ROTATE >*/
  */
 typedef enum { /*< prefix=CLUTTER_REQUEST >*/
   CLUTTER_REQUEST_HEIGHT_FOR_WIDTH,
-  CLUTTER_REQUEST_WIDTH_FOR_HEIGHT
+  CLUTTER_REQUEST_WIDTH_FOR_HEIGHT,
+  CLUTTER_REQUEST_CONTENT_SIZE
 } ClutterRequestMode;
 
 /**
@@ -734,7 +737,7 @@ typedef enum { /*< flags prefix=CLUTTER_EVENT >*/
  * @CLUTTER_BUTTON_PRESS: Pointer button press event
  * @CLUTTER_BUTTON_RELEASE: Pointer button release event
  * @CLUTTER_SCROLL: Pointer scroll event
- * @CLUTTER_STAGE_STATE: Stage stage change event
+ * @CLUTTER_STAGE_STATE: Stage state change event
  * @CLUTTER_DESTROY_NOTIFY: Destroy notification event
  * @CLUTTER_CLIENT_MESSAGE: Client message event
  * @CLUTTER_DELETE: Stage delete event
@@ -1002,6 +1005,25 @@ typedef enum { /*< prefix=CLUTTER_SWIPE_DIRECTION >*/
   CLUTTER_SWIPE_DIRECTION_RIGHT = 1 << 3
 } ClutterSwipeDirection;
 
+/**
+ * ClutterPanAxis:
+ * @CLUTTER_PAN_AXIS_NONE: No constraint
+ * @CLUTTER_PAN_X_AXIS: Set a constraint on the X axis
+ * @CLUTTER_PAN_Y_AXIS: Set a constraint on the Y axis
+ *
+ * The axis of the constraint that should be applied on the
+ * panning action
+ *
+ * Since: 1.12
+ */
+typedef enum { /*< prefix=CLUTTER_PAN >*/
+  CLUTTER_PAN_AXIS_NONE = 0,
+
+  CLUTTER_PAN_X_AXIS,
+  CLUTTER_PAN_Y_AXIS
+} ClutterPanAxis;
+
+
 /**
  * ClutterTableAlignment:
  * @CLUTTER_TABLE_ALIGNMENT_START: Align the child to the top or to the
@@ -1338,6 +1360,29 @@ typedef enum { /*< prefix=CLUTTER_ZOOM >*/
   CLUTTER_ZOOM_BOTH
 } ClutterZoomAxis;
 
+/**
+ * ClutterGestureTriggerEdge:
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_NONE: Tell #ClutterGestureAction that
+ * the gesture must begin immediately and there's no drag limit that
+ * will cause its cancellation;
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_AFTER: Tell #ClutterGestureAction that
+ * it needs to wait until the drag threshold has been exceeded before
+ * considering that the gesture has begun;
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_BEFORE: Tell #ClutterGestureAction that
+ * the gesture must begin immediately and that it must be cancelled
+ * once the drag exceed the configured threshold.
+ *
+ * Enum passed to the clutter_gesture_action_set_threshold_trigger_edge()
+ * function.
+ *
+ * Since: 1.18
+ */
+typedef enum {
+  CLUTTER_GESTURE_TRIGGER_EDGE_NONE  = 0,
+  CLUTTER_GESTURE_TRIGGER_EDGE_AFTER,
+  CLUTTER_GESTURE_TRIGGER_EDGE_BEFORE
+} ClutterGestureTriggerEdge;
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ENUMS_H__ */
